# Settings

## Minimal settings

As a bare minimum, you need to specify a `projects_path` and a `templates_path`.

If you don't have the variables configured, you will be prompted to enter them when you run any command:

```
sereto new TEST
It seems like this is the first time you're running the tool. Let's set it up!

📂 Enter the path to the projects directory: /home/demo/sereto_projects
📂 Enter the path to the templates directory: /home/demo/sereto_templates
```

### `projects_path`

The path to the directory where the projects are located.

### `templates_path`

The path to the directory where the templates are located.
